@@ -1,11 +1,21 @@
 #include <stdlib.h>
 #include <unistd.h>
 
+void *a()
+{
+  return malloc(1000);
+}
+
+void *b()
+{
+  return a();
+}
+
 int main()
 {
   char *block;
-  
-  block = malloc(1000);
+
+  block = b();
   block = malloc(1000);
   free(block);
 
